==> jc-1.4.0.tar.gz: gnu/xml/dom/DomComment.h <==
// public class gnu.xml.dom.DomComment

// class file dependencies
// @dep_class ac70db9f005d2722 gnu_xml_dom_DomCharacterData
// @dep_class deacc61ac226b7ec gnu_xml_dom_DomComment
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomCharacterData

#include "gnu/xml/dom/DomCharacterData.h"

#ifndef _JC_gnu_xml_dom_DomComment_H_
#define _JC_gnu_xml_dom_DomComment_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomComment$sub_refs	_jc_gnu_xml_dom_DomComment$sub_refs;
typedef struct _jc_gnu_xml_dom_DomComment$sub_nonrefs	_jc_gnu_xml_dom_DomComment$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomComment$refs	_jc_gnu_xml_dom_DomComment$refs;
typedef struct _jc_gnu_xml_dom_DomComment$nonrefs	_jc_gnu_xml_dom_DomComment$nonrefs;
typedef struct _jc_gnu_xml_dom_DomComment$object	_jc_gnu_xml_dom_DomComment$object;

typedef const struct _jc_gnu_xml_dom_DomComment$vmethods	_jc_gnu_xml_dom_DomComment$vmethods;
typedef const struct _jc_gnu_xml_dom_DomComment$vtable	_jc_gnu_xml_dom_DomComment$vtable;
typedef const struct _jc_gnu_xml_dom_DomComment$vtype	_jc_gnu_xml_dom_DomComment$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomComment$method$_init$629ade8a5a8e9c46(_jc_env *, struct _jc_gnu_xml_dom_DomComment$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomComment$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomComment$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomComment$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomComment$vmethods {
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomComment$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomComment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomCharacterData$vmethods	gnu_xml_dom_DomCharacterData;
	_jc_gnu_xml_dom_DomComment$vmethods	gnu_xml_dom_DomComment;
};

// Vtype
struct _jc_gnu_xml_dom_DomComment$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomComment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomComment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomComment$refs {
    _jc_gnu_xml_dom_DomComment$sub_refs	gnu_xml_dom_DomComment;
    _jc_gnu_xml_dom_DomCharacterData$sub_refs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomComment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomComment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomCharacterData$sub_nonrefs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomComment$sub_nonrefs	gnu_xml_dom_DomComment;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomComment$object {
	_jc_gnu_xml_dom_DomComment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomComment$vtype	*vtype;
	_jc_gnu_xml_dom_DomComment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomComment$vtype _jc_gnu_xml_dom_DomComment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomComment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomComment$class_object;

#endif	/* _JC_gnu_xml_dom_DomComment_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomComment.h <==
// public class gnu.xml.dom.DomComment

// class file dependencies
// @dep_class ac70db9f005d2722 gnu_xml_dom_DomCharacterData
// @dep_class deacc61ac226b7ec gnu_xml_dom_DomComment
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomCharacterData

#include "gnu/xml/dom/DomCharacterData.h"

#ifndef _JC_gnu_xml_dom_DomComment_H_
#define _JC_gnu_xml_dom_DomComment_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomComment$sub_refs	_jc_gnu_xml_dom_DomComment$sub_refs;
typedef struct _jc_gnu_xml_dom_DomComment$sub_nonrefs	_jc_gnu_xml_dom_DomComment$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomComment$refs	_jc_gnu_xml_dom_DomComment$refs;
typedef struct _jc_gnu_xml_dom_DomComment$nonrefs	_jc_gnu_xml_dom_DomComment$nonrefs;
typedef struct _jc_gnu_xml_dom_DomComment$object	_jc_gnu_xml_dom_DomComment$object;

typedef const struct _jc_gnu_xml_dom_DomComment$vmethods	_jc_gnu_xml_dom_DomComment$vmethods;
typedef const struct _jc_gnu_xml_dom_DomComment$vtable	_jc_gnu_xml_dom_DomComment$vtable;
typedef const struct _jc_gnu_xml_dom_DomComment$vtype	_jc_gnu_xml_dom_DomComment$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomComment$method$_init$629ade8a5a8e9c46(_jc_env *, struct _jc_gnu_xml_dom_DomComment$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomComment$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomComment$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomComment$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomComment$vmethods {
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomComment$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomComment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomCharacterData$vmethods	gnu_xml_dom_DomCharacterData;
	_jc_gnu_xml_dom_DomComment$vmethods	gnu_xml_dom_DomComment;
};

// Vtype
struct _jc_gnu_xml_dom_DomComment$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomComment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomComment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomComment$refs {
    _jc_gnu_xml_dom_DomComment$sub_refs	gnu_xml_dom_DomComment;
    _jc_gnu_xml_dom_DomCharacterData$sub_refs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomComment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomComment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomCharacterData$sub_nonrefs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomComment$sub_nonrefs	gnu_xml_dom_DomComment;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomComment$object {
	_jc_gnu_xml_dom_DomComment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomComment$vtype	*vtype;
	_jc_gnu_xml_dom_DomComment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomComment$vtype _jc_gnu_xml_dom_DomComment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomComment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomComment$class_object;

#endif	/* _JC_gnu_xml_dom_DomComment_H_ */
